dashboard: remove vetall, update misc-compile builders

Updates golang/go#31916

Change-Id: I38c08955bdb4ff2b0963d5c91c6e8f78267b8004
Reviewed-on: https://go-review.googlesource.com/c/build/+/176599
Reviewed-by: Brad Fitzpatrick <bradfitz@golang.org>
diff --git a/dashboard/builders_test.go b/dashboard/builders_test.go
index 29ab3ac..57c0a45 100644
--- a/dashboard/builders_test.go
+++ b/dashboard/builders_test.go
@@ -89,7 +89,10 @@
 				"linux-386",
 				"linux-amd64",
 				"linux-amd64-race",
-				"misc-compile",
+				"misc-compile-other",
+				"misc-compile-darwin",
+				"misc-compile-linuxarm",
+				"misc-compile-solaris",
 				"misc-compile-freebsd",
 				"misc-compile-mips",
 				"misc-compile-nacl",
@@ -97,7 +100,6 @@
 				"misc-compile-openbsd",
 				"misc-compile-plan9",
 				"misc-compile-ppc",
-				"misc-vet-vetall",
 				"nacl-amd64p32",
 				"openbsd-amd64-64",
 				"windows-386-2008",
@@ -114,14 +116,17 @@
 				"linux-386",
 				"linux-amd64",
 				"linux-amd64-race",
-				"misc-compile",
+				"misc-compile-darwin",
 				"misc-compile-freebsd",
+				"misc-compile-linuxarm",
 				"misc-compile-mips",
 				"misc-compile-nacl",
 				"misc-compile-netbsd",
 				"misc-compile-openbsd",
+				"misc-compile-other",
 				"misc-compile-plan9",
 				"misc-compile-ppc",
+				"misc-compile-solaris",
 				"nacl-amd64p32",
 				"openbsd-amd64-64",
 				"windows-386-2008",
@@ -262,10 +267,6 @@
 		{b("linux-amd64", "net"), both},
 		{b("linux-amd64", "sys"), both},
 
-		{b("misc-vet-vetall", "go"), both},
-		{b("misc-vet-vetall@go1.11", "go"), none},
-		{b("misc-vet-vetall@go1.12", "go"), none},
-
 		// Don't test all subrepos on all the builders.
 		{b("linux-amd64-ssacheck", "net"), none},
 		{b("linux-amd64-ssacheck@go1.10", "net"), none},
diff --git a/dashboard/builders.go b/dashboard/builders.go
index 988c08c..d436e2b 100644
--- a/dashboard/builders.go
+++ b/dashboard/builders.go
@@ -870,7 +870,7 @@
 // allowed to make outbound network requests. This is only enforced
 // on some builders. (Currently most Linux ones)
 func (c *BuildConfig) OutboundNetworkAllowed() bool {
-	return c.Name == "misc-vet-vetall" || c.IsLongTest()
+	return c.IsLongTest()
 }
 
 func (c *BuildConfig) GoInstallRacePackages() []string {
@@ -1381,22 +1381,11 @@
 		})
 	}
 
-	// Add the -vetall builder. The builder name suffix "-vetall" is recognized by cmd/dist/test.go
-	// to only run the "go vet std cmd" test and no others.
-	addBuilder(BuildConfig{
-		Name:     "misc-vet-vetall",
-		HostType: "host-linux-jessie",
-		Notes:    "Runs vet over the standard library.",
-		buildsRepo: func(repo, branch, goBranch string) bool {
-			return repo == "go" && branch == "master"
-		},
-		tryBot: defaultTrySet(),
-		env: []string{
-			"GO_DISABLE_OUTBOUND_NETWORK=1",
-		},
-		numTestHelpers: 5,
-	})
-
+	// addMiscCompile adds a misc-compile builder that runs
+	// buildall.bash on a subset of platforms matching the egrep
+	// pattern rx. The pattern is matched against the "go tool
+	// dist list" name, but with hyphens instead of forward
+	// slashes ("linux-amd64", etc).
 	addMiscCompile := func(suffix, rx string) {
 		addBuilder(BuildConfig{
 			Name:     "misc-compile" + suffix,
@@ -1407,23 +1396,28 @@
 			},
 			tryOnly:     true,
 			CompileOnly: true,
-			Notes:       "Runs buildall.sh to cross-compile std packages for " + rx + ", but doesn't run any tests.",
+			Notes:       "Runs buildall.sh to cross-compile & vet std+cmd packages for " + rx + ", but doesn't run any tests.",
 			allScriptArgs: []string{
 				// Filtering pattern to buildall.bash:
 				rx,
 			},
 		})
 	}
-	addMiscCompile("", "^(linux-arm64|linux-s390x|solaris-amd64|darwin-386)$") // 4 ports
-	addMiscCompile("-nacl", "^nacl")                                           // 3
-	addMiscCompile("-mips", "^linux-mips")                                     // 4
-	addMiscCompile("-ppc", "^linux-ppc64")                                     // 2
-	addMiscCompile("-plan9", "^plan9-")                                        // 3
-	addMiscCompile("-freebsd", "^freebsd-")                                    // 3
-	addMiscCompile("-netbsd", "^netbsd-")                                      // 3
-	addMiscCompile("-openbsd", "^openbsd-")                                    // 3
-	// TODO: Issue 25963, get the misc-compile trybots for mobile working, and then:
-	// addMiscCompile("-mobile", "(^android|darwin-arm64)")                       // 5 ports
+	addMiscCompile("-linuxarm", "^linux-arm")        // 2: arm, arm64
+	addMiscCompile("-darwin", "^darwin")             // 4: 386, amd64 + iOS: armb, arm64
+	addMiscCompile("-nacl", "^nacl")                 // 3: arm, 386, amd64p32
+	addMiscCompile("-mips", "^linux-mips")           // 4: mips, mipsle, mips64, mips64le
+	addMiscCompile("-ppc", "^(linux-ppc64|aix-)")    // 3: linux-ppc64{,le}, aix-ppc64
+	addMiscCompile("-solaris", "^(solaris|illumos)") // 2: both amd64
+	addMiscCompile("-plan9", "^plan9-")              // 3: amd64, 386, arm
+	addMiscCompile("-freebsd", "^freebsd-(386|arm)") // 2: 386, arm (amd64 already trybot)
+	addMiscCompile("-netbsd", "^netbsd-")            // 4: amd64, 386, arm, arm64
+	addMiscCompile("-openbsd", "^openbsd-")          // 4: amd64, 386, arm, arm64
+	// And 3 that don't fit above:
+	addMiscCompile("-other", "^(windows-arm|linux-s390x|dragonfly-amd64)$")
+	// TODO: Issue 25963, get the misc-compile trybots for
+	// subrepos too, so "mobile" can at least be included as a
+	// misc-compile for ^android- and ^darwin-arm.
 
 	addBuilder(BuildConfig{
 		Name:      "linux-amd64-nocgo",